@@ -1,6 +1,8 @@
 #' Fieldbook experimental designs
 #'
 #' Invoke RStudio addin to create field book designs
+#' 
+#' @param dependencies Install package dependencies for run the app
 #'
 #' @details
 #'
@@ -20,7 +22,20 @@
 #' 
 #' @export
 
-tarpuy <- function() {
+tarpuy <- function(dependencies = FALSE) {
+  
+  message("
+  - If is the first time running Tarpuy consider install the app dependencies:
+  > inti::tarpuy(dependencies = TRUE)
+  - Demo: 
+  > https://inkaverse.com/articles/apps
+          ")
+  
+  if (dependencies == TRUE ) {
+    
+    source("https://raw.githubusercontent.com/Flavjack/inti/master/inst/tarpuy/setup.r")
+    
+  }
   
   appDir <- system.file("tarpuy", package = "inti")
   
