@@ -1,27 +1,41 @@
+# -------------------------------------------------------------------------
 # tarpuy ------------------------------------------------------------------
 # -------------------------------------------------------------------------
+#> open https://flavjack.github.io/inti/
+#> open https://flavjack.shinyapps.io/tarpuy/
+#> author .: Flavio Lozano-Isla (lozanoisla.com)
+#> date .: 2020-11-14
+# -------------------------------------------------------------------------
 
-# open https://flavjack.shinyapps.io/tarpuy/
-# open http://localhost:1221/
-
+# -------------------------------------------------------------------------
 # packages ----------------------------------------------------------------
 # -------------------------------------------------------------------------
 
+#> devtools::install_github("flavjack/inti")
+
+if (file.exists("setup.R")) { source("setup.R") }
+
 library(shiny)
 library(inti)
 library(metathis)
 library(tidyverse)
 library(googlesheets4)
 library(googleAuthR)
-library(bootstraplib)
+library(bslib)
 library(shinydashboard)
 library(stringi)
+library(BiocManager)
 
-options("googleAuthR.scopes.selected" = c("https://www.googleapis.com/auth/spreadsheets"))
+options(repos = BiocManager::repositories())
+options("googleAuthR.scopes.selected" = c("https://www.googleapis.com/auth/spreadsheets"
+                                          , "https://www.googleapis.com/auth/userinfo.email"
+                                          ))
 options(gargle_oob_default = TRUE)
 options(shiny.port = 1221)
-gar_set_client(web_json = "www/cloud.json")
 
+if (file.exists("www/cloud.json")) gar_set_client(web_json = "www/cloud.json")
+
+# -------------------------------------------------------------------------
 # app ---------------------------------------------------------------------
 # -------------------------------------------------------------------------
 
@@ -42,8 +56,28 @@ shinyServer(function(input, output, session) {
 # auth --------------------------------------------------------------------
 
   gar_shiny_auth(session)
-
+  
+  # longin vs local ---------------------------------------------------------
+  
   access_token <- callModule(googleAuth_js, "js_token")
+  
+
+  output$login <- renderUI({
+    
+    if (file.exists("www/cloud.json")) {
+      
+      googleAuth_jsUI("js_token"
+                      , login_text = "LogIn"
+                      , logout_text = "LogOut"
+                      )
+      
+    } else {
+      
+      actionButton("local_user", "Local", class = "btn-success")
+      
+    }
+    
+  })
 
   gs <- reactive({
 
@@ -100,7 +134,7 @@ shinyServer(function(input, output, session) {
       )
       
     }
-
+    
     validate( need( gs4_has_token(), "LogIn and insert a url" ) )
     
     gs_created <<- gs4_create(
